first_letter_range

Function first_letter_range 

fn first_letter_range(text: &str) -> Range<usize> 
Computes the range of the first letter.

The range includes any preceding punctuation, and any spaces interleaved within the preceding punctuation or between the preceding punctuation and the first letter/number/symbol. Succeeding punctuation are included in the range, but any space following the letter/number/symbol ends the range. Intervening succeeding spaces are not supported yet.

https://drafts.csswg.org/css-pseudo/#first-letter-pattern